"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.destination = void 0;
const tslib_1 = require("tslib");
const shim_1 = require("@segment/browser-destination-runtime/shim");
const actions_core_1 = require("@segment/actions-core");
const sync_1 = tslib_1.__importDefault(require("./sync"));
const presets = [
    {
        name: 'Sync Anonymous ID',
        subscribe: 'type = "page" or type = "track" or type = "identify"',
        partnerAction: 'sync',
        mapping: (0, actions_core_1.defaultValues)(sync_1.default.fields),
        type: 'automatic'
    }
];
exports.destination = {
    name: 'CDP Resolution',
    slug: 'actions-cdpresolution',
    mode: 'device',
    description: 'Sync Segment user identifier to CDP Resolution',
    settings: {
        clientIdentifier: {
            label: 'Client Identifier',
            description: 'Client identifier provided by CDP Resolution [Hashed Account ID]',
            type: 'string',
            required: true
        },
        endpoint: {
            label: 'CDP Resolution Endpoint',
            description: 'Identity resolution endpoint. [CDP Resolution documentation](https://www.cdpresolution.com/docs/)',
            type: 'string',
            format: 'uri',
            choices: [{ label: 'CDPRes-Endpoint', value: 'https://a.usbrowserspeed.com/cs' }],
            default: 'https://a.usbrowserspeed.com/cs',
            required: true
        }
    },
    initialize: async (_, deps) => {
        window.cdpResolution = {
            sync: async (endpoint, clientIdentifier, anonymousId) => {
                let cdpcookieset = '';
                const name = 'cdpresolutionset' + '=';
                const ca = document.cookie.split(';');
                for (let i = 0; i < ca.length; i++) {
                    let c = ca[i];
                    while (c.charAt(0) == ' ') {
                        c = c.substring(1);
                    }
                    if (c.indexOf(name) == 0) {
                        cdpcookieset = c.substring(name.length, c.length);
                    }
                }
                const pid = '48a021d87720f17403d730658979d7f60e9cec91937e82072c66f611748dd47d';
                const userAnonymousId = String(anonymousId);
                const baseUrl = endpoint;
                const partnerUserId = {
                    client_id: clientIdentifier,
                    visitor_id: userAnonymousId
                };
                const partnerUserIdStr = encodeURIComponent(JSON.stringify(partnerUserId));
                const endpointUrl = userAnonymousId
                    ? `${baseUrl}?pid=${pid}&puid=${partnerUserIdStr}&anonymousId=${encodeURIComponent(userAnonymousId)}`
                    : baseUrl;
                if (cdpcookieset == '') {
                    document.cookie = 'cdpresolutionset=true';
                    await deps.loadScript(endpointUrl);
                    return;
                }
            }
        };
        return window.cdpResolution;
    },
    presets,
    actions: {
        sync: sync_1.default
    }
};
exports.default = (0, shim_1.browserDestination)(exports.destination);
//# sourceMappingURL=index.js.map